@@ -4,7 +4,7 @@
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -23,24 +23,23 @@
 
 package com.mysql.jdbc.exceptions;
 
-public class MySQLInvalidAuthorizationSpecException extends
-		MySQLNonTransientException {
+public class MySQLInvalidAuthorizationSpecException extends MySQLNonTransientException {
 
-	static final long serialVersionUID = 6878889837492500030L;
+    static final long serialVersionUID = 6878889837492500030L;
 
-	public MySQLInvalidAuthorizationSpecException() {
-		super();
-	}
+    public MySQLInvalidAuthorizationSpecException() {
+        super();
+    }
 
-	public MySQLInvalidAuthorizationSpecException(String reason, String SQLState, int vendorCode) {
-		super(reason, SQLState, vendorCode);
-	}
+    public MySQLInvalidAuthorizationSpecException(String reason, String SQLState, int vendorCode) {
+        super(reason, SQLState, vendorCode);
+    }
 
-	public MySQLInvalidAuthorizationSpecException(String reason, String SQLState) {
-		super(reason, SQLState);
-	}
+    public MySQLInvalidAuthorizationSpecException(String reason, String SQLState) {
+        super(reason, SQLState);
+    }
 
-	public MySQLInvalidAuthorizationSpecException(String reason) {
-		super(reason);
-	}
+    public MySQLInvalidAuthorizationSpecException(String reason) {
+        super(reason);
+    }
 }
