@@ -4,7 +4,7 @@
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -27,54 +27,46 @@ import testsuite.BaseTestCase;
 
 /**
  * Tests SSL functionality in the driver.
- * 
- * @author Mark Matthews
  */
 public class SSLTest extends BaseTestCase {
-	// ~ Constructors
-	// -----------------------------------------------------------
+    /**
+     * Constructor for SSLTest.
+     * 
+     * @param name
+     *            the name of the test to run.
+     */
+    public SSLTest(String name) {
+        super(name);
 
-	/**
-	 * Constructor for SSLTest.
-	 * 
-	 * @param name
-	 *            the name of the test to run.
-	 */
-	public SSLTest(String name) {
-		super(name);
+        System.setProperty("javax.net.debug", "all");
 
-		System.setProperty("javax.net.debug", "all");
+        StringBuilder sslUrl = new StringBuilder(dbUrl);
 
-		StringBuffer sslUrl = new StringBuffer(dbUrl);
+        if (dbUrl.indexOf("?") == -1) {
+            sslUrl.append("?");
+        } else {
+            sslUrl.append("&");
+        }
 
-		if (dbUrl.indexOf("?") == -1) {
-			sslUrl.append("?");
-		} else {
-			sslUrl.append("&");
-		}
+        sslUrl.append("useSSL=true");
+    }
 
-		sslUrl.append("useSSL=true");
-	}
+    /**
+     * Runs all test cases in this test suite
+     * 
+     * @param args
+     */
+    public static void main(String[] args) {
+        junit.textui.TestRunner.run(SSLTest.class);
+    }
 
-	// ~ Methods
-	// ----------------------------------------------------------------
-
-	/**
-	 * Runs all test cases in this test suite
-	 * 
-	 * @param args
-	 */
-	public static void main(String[] args) {
-		junit.textui.TestRunner.run(SSLTest.class);
-	}
-
-	/**
-	 * Tests SSL Connection
-	 * 
-	 * @throws Exception
-	 *             if an error occurs
-	 */
-	public void testConnect() throws Exception {
-		System.out.println("<<<<<<<<<<< Look for SSL debug output >>>>>>>>>>>");
-	}
+    /**
+     * Tests SSL Connection
+     * 
+     * @throws Exception
+     *             if an error occurs
+     */
+    public void testConnect() throws Exception {
+        System.out.println("<<<<<<<<<<< Look for SSL debug output >>>>>>>>>>>");
+    }
 }
