@@ -4,7 +4,7 @@
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -29,57 +29,52 @@ import com.mysql.jdbc.util.ServerController;
 
 /**
  * Demonstrates usage of the ServerController class.
- * 
- * @author Mark Matthews
- * @version $Id: ServerControllerTest.java,v 1.1.2.1 2005/05/13 18:58:37
- *          mmatthews Exp $
  */
 public class ServerControllerTest extends BaseTestCase {
 
-	private String baseDir;
+    private String baseDir;
 
-	/**
-	 * Creates a ServerControllerTest testcase.
-	 * 
-	 * @param name
-	 *            the name of the test to run.
-	 */
-	public ServerControllerTest(String name) {
-		super(name);
+    /**
+     * Creates a ServerControllerTest testcase.
+     * 
+     * @param name
+     *            the name of the test to run.
+     */
+    public ServerControllerTest(String name) {
+        super(name);
 
-		this.baseDir = System
-				.getProperty("com.mysql.jdbc.test.ServerController.basedir");
-	}
+        this.baseDir = System.getProperty("com.mysql.jdbc.test.ServerController.basedir");
+    }
 
-	/**
-	 * Runs all test cases in this test suite
-	 * 
-	 * @param args
-	 */
-	public static void main(String[] args) {
-		junit.textui.TestRunner.run(ServerControllerTest.class);
-	}
+    /**
+     * Runs all test cases in this test suite
+     * 
+     * @param args
+     */
+    public static void main(String[] args) {
+        junit.textui.TestRunner.run(ServerControllerTest.class);
+    }
 
-	/**
-	 * Demonstrates usage of the ServerController class.
-	 * 
-	 * This test is only run if the property
-	 * 'com.mysql.jdbc.test.ServerController.basedir' is set.
-	 * 
-	 * @throws Exception
-	 *             if an error occurs.
-	 */
-	public void testServerController() throws Exception {
+    /**
+     * Demonstrates usage of the ServerController class.
+     * 
+     * This test is only run if the property
+     * 'com.mysql.jdbc.test.ServerController.basedir' is set.
+     * 
+     * @throws Exception
+     *             if an error occurs.
+     */
+    public void testServerController() throws Exception {
 
-		if (this.baseDir != null) {
-			System.out.println("Starting server @ " + this.baseDir);
+        if (this.baseDir != null) {
+            System.out.println("Starting server @ " + this.baseDir);
 
-			ServerController controller = new ServerController(this.baseDir);
-			System.out.println(controller.start());
-			System.out.println("Hit enter to stop server....");
-			System.in.read();
-			controller.stop(true);
+            ServerController controller = new ServerController(this.baseDir);
+            System.out.println(controller.start());
+            System.out.println("Hit enter to stop server....");
+            System.in.read();
+            controller.stop(true);
 
-		}
-	}
+        }
+    }
 }
