@@ -4,7 +4,7 @@
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -31,25 +31,18 @@ import com.mysql.jdbc.NonRegisteringDriver;
 
 /**
  * Used for testing the ConnectionPropertiesTransform functionality.
- * 
- * @author Mark Matthews
- * 
- * @version $Id: SimpleTransformer.java,v 1.1.2.1 2005/05/13 18:58:37 mmatthews
- *          Exp $
  */
 public class SimpleTransformer implements ConnectionPropertiesTransform {
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see com.mysql.jdbc.ConnectionPropertiesTransform#transformProperties(java.util.Properties)
-	 */
-	public Properties transformProperties(Properties props) throws SQLException {
-		props
-				.setProperty(NonRegisteringDriver.HOST_PROPERTY_KEY,
-						"albequerque");
+    /*
+     * (non-Javadoc)
+     * 
+     * @see com.mysql.jdbc.ConnectionPropertiesTransform#transformProperties(java.util.Properties)
+     */
+    public Properties transformProperties(Properties props) throws SQLException {
+        props.setProperty(NonRegisteringDriver.HOST_PROPERTY_KEY, "albequerque");
 
-		return props;
-	}
+        return props;
+    }
 
 }
