@@ -4,7 +4,7 @@
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -30,55 +30,46 @@ import java.util.Properties;
 import com.mysql.jdbc.ConnectionLifecycleInterceptor;
 
 public class TestLifecycleInterceptor implements ConnectionLifecycleInterceptor {
-	static int transactionsBegun = 0;
-	static int transactionsCompleted = 0;
+    static int transactionsBegun = 0;
+    static int transactionsCompleted = 0;
 
-	public void close() throws SQLException {
+    public void close() throws SQLException {
+    }
 
-	}
+    public boolean commit() throws SQLException {
+        return true;
+    }
 
-	public boolean commit() throws SQLException {
+    public boolean rollback() throws SQLException {
+        return true;
+    }
 
-		return true;
-	}
+    public boolean rollback(Savepoint s) throws SQLException {
+        return true;
+    }
 
-	public boolean rollback() throws SQLException {
+    public boolean setAutoCommit(boolean flag) throws SQLException {
+        return true;
+    }
 
-		return true;
-	}
+    public boolean setCatalog(String catalog) throws SQLException {
+        return true;
+    }
 
-	public boolean rollback(Savepoint s) throws SQLException {
+    public boolean transactionBegun() throws SQLException {
+        transactionsBegun++;
+        return true;
+    }
 
-		return true;
-	}
+    public boolean transactionCompleted() throws SQLException {
+        transactionsCompleted++;
+        return true;
+    }
 
-	public boolean setAutoCommit(boolean flag) throws SQLException {
+    public void destroy() {
+    }
 
-		return true;
-	}
-
-	public boolean setCatalog(String catalog) throws SQLException {
-
-		return true;
-	}
-
-	public boolean transactionBegun() throws SQLException {
-		transactionsBegun++;
-		return true;
-	}
-
-	public boolean transactionCompleted() throws SQLException {
-		transactionsCompleted++;
-		return true;
-	}
-
-	public void destroy() {
-
-	}
-
-	public void init(com.mysql.jdbc.Connection conn, Properties props)
-			throws SQLException {
-
-	}
+    public void init(com.mysql.jdbc.Connection conn, Properties props) throws SQLException {
+    }
 
 }
\ No newline at end of file
